@@ -245,7 +245,7 @@ class Column(object):
                     fsize = int(_convert_format(format)[1:])
                     return chararray.array(array, itemsize=fsize)
                 else:
-                    numpy_format =  _convert_format(format)
+                    numpy_format = _convert_format(format)
                     return _convert_array(array, np.dtype(numpy_format))
             elif 'X' not in format and 'P' not in format:
                 (repeat, fmt, option) = _parse_tformat(format)
@@ -290,14 +290,15 @@ class ColDefs(object):
         Parameters
         ----------
 
-        input : sequence of `Column` objects
-            an (table) HDU
+        input :
+            An existing table HDU, an existing ColDefs, or recarray
 
         **(Deprecated)** tbtype : str, optional
             which table HDU, ``"BinTableHDU"`` (default) or
             ``"TableHDU"`` (text table).
-            now ColDefs for a normal (binary) table by default, but converted
+            Now ColDefs for a normal (binary) table by default, but converted
             automatically to ASCII table ColDefs in the appropriate contexts
+            (namely, when creating an ASCII table).
         """
 
         from pyfits.hdu.table import _TableBaseHDU
@@ -329,7 +330,7 @@ class ColDefs(object):
                     format = _convert_format(ftype, reverse=True)
                 # Determine the appropriate dimensions for items in the column
                 # (typically just 1D)
-                dim = input.dtype[idx].shape
+                dim = input.dtype[idx].shape[::-1]
                 if dim and (len(dim) > 1 or 'A' in format):
                     if 'A' in format:
                         # n x m string arrays must include the max string
