@@ -12,9 +12,9 @@ from pyfits.util import lazyproperty, _pad_length
 
 try:
     from pyfits import compression
-    COMPRESSION_SUPPORTED = True
+    COMPRESSION_SUPPORTED = COMPRESSION_ENABLED = True
 except ImportError:
-    COMPRESSION_SUPPORTED = False
+    COMPRESSION_SUPPORTED = COMPRESSION_ENABLED = False
 
 
 # Default compression parameter values
@@ -271,20 +271,25 @@ class CompImageHDU(BinTableHDU):
         if card.key != 'XTENSION':
             return False
 
-        xtension = card.value.rstrip()
+        xtension = card.value
+        if isinstance(xtension, basestring):
+            xtension = xtension.rstrip()
+
         if xtension not in ('BINTABLE', 'A3DTABLE'):
             return False
 
         if 'ZIMAGE' not in header or header['ZIMAGE'] != True:
             return False
 
-        if COMPRESSION_SUPPORTED: # Redundant
+        if COMPRESSION_SUPPORTED and COMPRESSION_ENABLED:
             return True
+        elif not COMPRESSION_SUPPORTED:
+            warnings.warn('Failure matching header to a compressed image '
+                          'HDU.\nThe compression module is not available.\n'
+                          'The HDU will be treated as a Binary Table HDU.')
+            return False
         else:
-            warnings.warn(
-                'Failure matching header to a compressed image HDU.')
-            warnings.warn('The compression module is not available.')
-            warnings.warn('The HDU will be treated as a Binary Table HDU.')
+            # Compression is supported but disabled; just pass silently (#92)
             return False
 
     def updateHeaderData(self, image_header,
@@ -518,9 +523,9 @@ class CompImageHDU(BinTableHDU):
         # Set default tile dimensions for HCOMPRESS_1
 
         if compressionType == 'HCOMPRESS_1':
-            if self._image_header['NAXIS'] < 2:
-                raise ValueError('Hcompress cannot be used with '
-                                 '1-dimensional images.')
+            if self._image_header['NAXIS'] != 2:
+                raise ValueError('Hcompress can only be used with '
+                                 '2-dimensional images.')
             elif self._image_header['NAXIS1'] < 4 or \
             self._image_header['NAXIS2'] < 4:
                 raise ValueError('Hcompress minimum image dimension is '
@@ -1470,7 +1475,7 @@ class CompImageHDU(BinTableHDU):
                 zval = 'ZVAL' + str(idx)
                 if self._header[zname] == 'SMOOTH':
                     hcompSmooth = self._header[zval]
-                i += 1
+                idx += 1
 
             zvalList.append(hcompSmooth)
 
