@@ -2,6 +2,7 @@ from __future__ import division # confidence high
 from __future__ import with_statement
 
 import gzip
+import os
 import warnings
 import zipfile
 
@@ -268,6 +269,26 @@ class TestFileFunctions(PyfitsTestCase):
         filelike.seek(0)
         assert_equal(len(pyfits.open(filelike)), 5)
 
+    def test_updated_file_permissions(self):
+        """
+        Regression test for #79.  Tests that when a FITS file is modified in
+        update mode, the file permissions are preserved.
+        """
+
+        filename = self.temp('test.fits')
+        hdul = [pyfits.PrimaryHDU(), pyfits.ImageHDU()]
+        hdul = pyfits.HDUList(hdul)
+        hdul.writeto(filename)
+
+        old_mode = os.stat(filename).st_mode
+
+        hdul = pyfits.open(filename, mode='update')
+        hdul.insert(1, pyfits.ImageHDU())
+        hdul.flush()
+        hdul.close()
+
+        assert_equal(old_mode, os.stat(filename).st_mode)
+
     def _make_gzip_file(self):
         gzfile = self.temp('test0.fits.gz')
         with open(self.data('test0.fits'), 'rb') as f:
@@ -341,6 +362,21 @@ class TestStreamingFunctions(PyfitsTestCase):
             shdu = self._make_streaming_hdu(f)
             shdu.write(arr)
 
+    # TODO: This test is temporarily borrowed from the header-refactoring
+    # branch as a regression test for ticket #69; it can be removed when the
+    # header-refactoring branch is merged into trunk
+    def test_update_comment(self):
+        hdul = pyfits.open(self.data('arange.fits'))
+        hdul[0].header.update('FOO', 'BAR', 'BAZ')
+        hdul.writeto(self.temp('test.fits'))
+
+        hdul = pyfits.open(self.temp('test.fits'), mode='update')
+        hdul[0].header.ascard['FOO'].comment = 'QUX'
+        hdul.close()
+
+        hdul = pyfits.open(self.temp('test.fits'))
+        assert_equal(hdul[0].header.ascard['FOO'].comment, 'QUX')
+
     def _make_streaming_hdu(self, fileobj):
         hd = pyfits.Header()
         hd.update('SIMPLE', True, 'conforms to FITS standard')
