@@ -1605,13 +1605,13 @@ class TestTableFunctions(PyfitsTestCase):
         """
 
         data = np.rec.array(
-            [([1, 2, 3, 4], 'row1' * 2),
-             ([5, 6, 7, 8], 'row2' * 2),
-             ([9, 1, 2, 3], 'row3' * 2)], formats='4i4,a8')
+            [([0, 1, 2, 3, 4, 5], 'row1' * 2),
+             ([6, 7, 8, 9, 0, 1], 'row2' * 2),
+             ([2, 3, 4, 5, 6, 7], 'row3' * 2)], formats='6i4,a8')
 
         thdu = pyfits.new_table(data)
         # Modify the TDIM fields to my own specification
-        thdu.header.update('TDIM1', '(2,2)')
+        thdu.header.update('TDIM1', '(2,3)')
         thdu.header.update('TDIM2', '(4,2)')
 
         thdu.writeto(self.temp('newtable.fits'))
@@ -1624,11 +1624,11 @@ class TestTableFunctions(PyfitsTestCase):
 
         hdul.close()
 
-        assert_equal(c1.shape, (3, 2, 2))
+        assert_equal(c1.shape, (3, 3, 2))
         assert_equal(c2.shape, (3, 2))
-        assert_true((c1 == np.array([[[1, 2], [3, 4]],
-                                     [[5, 6], [7, 8]],
-                                     [[9, 1], [2, 3]]])).all())
+        assert_true((c1 == np.array([[[0, 1], [2, 3], [4, 5]],
+                                     [[6, 7], [8, 9], [0, 1]],
+                                     [[2, 3], [4, 5], [6, 7]]])).all())
         assert_true((c2 == np.array([['row1', 'row1'],
                                      ['row2', 'row2'],
                                      ['row3', 'row3']])).all())
@@ -1688,3 +1688,28 @@ class TestTableFunctions(PyfitsTestCase):
         assert_true((s1 == s2).all())
         assert_true((s2 == s3).all())
         assert_true((s3 == s4).all())
+
+    def test_attribute_field_shadowing(self):
+        """
+        Regression test for #86.
+
+        Numpy recarray objects have a poorly-considered feature of allowing
+        field access by attribute lookup.  However, if a field name conincides
+        with an existing attribute/method of the array, the existing name takes
+        precence (making the attribute-based field lookup completely unreliable
+        in general cases).
+
+        This ensures that any FITS_rec attributes still work correctly even
+        when there is a field with the same name as that attribute.
+        """
+
+        c1 = pyfits.Column(name='names', format='I', array=[1])
+        c2 = pyfits.Column(name='formats', format='I', array=[2])
+        c3 = pyfits.Column(name='other', format='I', array=[3])
+
+        t = pyfits.new_table([c1, c2, c3])
+        assert_equal(t.data.names, ['names', 'formats', 'other'])
+        assert_equal(t.data.formats, ['I'] * 3)
+        assert_true((t.data['names'] == [1]).all())
+        assert_true((t.data['formats'] == [2]).all())
+        assert_true((t.data.other == [3]).all())
